//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Data/ProjectionItems.cpp
//! @brief     Implements items related to projections over color map.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Data/ProjectionItems.h"
#include <stdexcept>

ProjectionContainerItem::ProjectionContainerItem()
    : MaskContainerItem()
{
}

void ProjectionContainerItem::insertMask(int row, MaskItem* maskItem)
{
    verifyMask(maskItem);
    MaskContainerItem::insertMask(row, maskItem);
}

void ProjectionContainerItem::addMask(MaskItem* maskItem)
{
    verifyMask(maskItem);
    MaskContainerItem::addMask(maskItem);
}

void ProjectionContainerItem::verifyMask(MaskItem* maskItem) const
{
    ASSERT(maskItem);

    ASSERT(dynamic_cast<HorizontalLineItem*>(maskItem)
           || dynamic_cast<VerticalLineItem*>(maskItem));
}

QVector<MaskItem*> ProjectionContainerItem::projectionsOfType(ProjectionType projectionType)
{
    if (projectionType == ProjectionType::Horizontal)
        return projections<HorizontalLineItem>();
    else if (projectionType == ProjectionType::Vertical)
        return projections<VerticalLineItem>();
    else
        ASSERT(false);
    return {};
}
